require File.expand_path '../../test_helper.rb', __FILE__

require 'fixtures'
require 'fake_apns_server'
require 'base64'
require 'timeout'

describe Crusade::APNS::PushNotification do
  let(:options) { Fixtures.default_configuration }
  subject { Crusade::APNS::PushNotification.new options, connection }
  let(:connection) { Crusade::APNS::SocketConnection.new options }

  describe 'send' do
    let(:server) { FakeApnsServer.new options }

    before do
      connection.host = '127.0.0.1'
      server.start
    end

    after  { server.stop  }

    let(:binary) do
<<-eof
AQAAAAAAAVGAACASNKAAXHsiYXBzIjp7ImFsZXJ0Ijp7InRpdGxlIjoidGhl
IHRpdGxlIiwiYm9keSI6InRoZSBib2R5IiwiYWN0aW9uIjoic3VibWl0In0s
InVybC1hcmdzIjpbImEiXX19
eof
    end

    it 'sends the binary representation of the notification' do
      subject.send Fixtures.default_apns_notification

      Timeout::timeout(1, ThreadError) { while(server.received.size == 0) ; end }

      server.received.last.must_equal Base64.decode64 binary
    end
  end
end