require File.expand_path '../../test_helper.rb', __FILE__

require 'crusade/apns/push_package_generator'

require 'fileutils'
require 'tmpdir'
require 'zip_support'

describe Crusade::APNS::PushPackageGenerator do
  let(:options) { Fixtures.default_configuration }
  let(:user_id) { '1234' }

  let(:generated)    { subject.generate user_id }
  let(:push_package) { generated[1] }
  let(:user_token)   { generated[0] }

  subject { Crusade::APNS::PushPackageGenerator.new options }

  describe 'generate' do
    let(:tmp_dir) { Dir.mktmpdir }

    after do
      FileUtils.remove_entry_secure push_package
      FileUtils.remove_entry_secure tmp_dir
    end

    it 'generates the push packages' do
      File.exists?(push_package).must_be_truthy

      files = ZipSupport.file_names(push_package)

      icons = %w(16x16 16x16@2x 32x32 32x32@2x 128x128 128x128@2x).map do |size|
        "icon.iconset/icon_#{size}.png"
      end

      files.must_equal_contents %w(manifest.json website.json signature icon.iconset/) + icons
      user_token.wont_be_nil
    end

    it 'can generate twice in a row' do
      subject.generate user_id
      subject.generate user_id

      File.exists?(push_package).must_be_truthy
    end
  end

  describe 'clean' do
    it 'removes the push package' do
      push_package

      subject.clean push_package

      File.exists?(push_package).must_equal false
    end

    it 'does not blow up if the file does not exist' do
      subject.clean 'foo'
    end
  end
end