require "socket"
require "openssl"
require "thread"

class FakeApnsServer
  attr_reader :received

  def initialize(configuration)
    self.port = 2195
    self.configuration = configuration
    self.received = []
  end

  def start
    cert = OpenSSL::PKCS12.new(File.read(configuration.certificate), configuration.certificate_password)
    
    server = TCPServer.new(port)

    ssl_context = OpenSSL::SSL::SSLContext.new

    ssl_context.cert = OpenSSL::X509::Certificate.new(cert.certificate.to_pem)
    ssl_context.key  = OpenSSL::PKey::RSA.new(cert.key.to_pem)
    ssl_server       = OpenSSL::SSL::SSLServer.new(server, ssl_context)

    launch_thread(ssl_server)
  end

  def stop
    thread.terminate
  end

  private

  attr_accessor :port, :configuration, :thread
  attr_writer :received

  def launch_thread(ssl_server)
    self.thread = Thread.new {
      loop do
        connection = ssl_server.accept
        while (line_in = connection.gets)
          register_received line_in.chomp
        end
      end
    }
  end

  def register_received line
    received << line
  end
end