require File.expand_path '../../test_helper.rb', __FILE__

require 'crusade/apns/configuration'

describe Crusade::APNS::Configuration do
  let(:described_class) { Crusade::APNS::Configuration }

  describe 'initialize' do
    let(:attributes) do
      {
        site_name: 'the website',
        push_id:   'web.example.com',
        url_format: 'http://example.com/%@',
        webservice_url: 'https://www.example.com/push',
        allowed_domains: ['http://acme.com'],
        iconset_dir: '/config/icons'
      }
    end

    subject { described_class.new attributes }

    describe 'minimum attributes' do
      it 'has a default certificate' do
        subject.certificate.must_equal 'config/push_certificate.p12'
      end

      it 'has no certificate password' do
        subject.certificate_password.must_be_nil
      end

      it 'sets the certificate' do
        subject = described_class.new attributes.merge(certificate: '/cert.p12')

        subject.certificate.must_equal '/cert.p12'
      end

      it 'sets the certificate password' do
        subject = described_class.new attributes.merge(certificate_password: 'pass')

        subject.certificate_password.must_equal 'pass'
      end

      it 'sets the site_name' do
        subject.site_name.must_equal 'the website'
      end

      it 'sets the push_id' do
        subject.push_id.must_equal 'web.example.com'
      end

      it 'sets the url_format' do
        subject.url_format.must_equal 'http://example.com/%@'
      end

      it 'sets the webservice_url' do
        subject.webservice_url.must_equal 'https://www.example.com/push'
      end

      it 'sets the allowed domains' do
        subject.allowed_domains.must_equal ['http://acme.com']
      end

      it 'sets the iconset_sir' do
        subject.iconset_dir.must_equal '/config/icons'
      end
    end

    describe 'iconset_files' do
      let(:iconset_files) { subject.iconset_files }

      it 'returns the 16x16 icons' do
        iconset_files.include?('/config/icons/icon_16x16.png').must_be_truthy
      end

      it 'returns the 16x1?6@2x icons' do
        iconset_files.include?('/config/icons/icon_16x16@2x.png').must_be_truthy
      end

      it 'returns the 32x32 icons' do
        iconset_files.include?('/config/icons/icon_32x32.png').must_be_truthy
      end

      it 'returns the 2x3?2@2x icons' do
        iconset_files.include?('/config/icons/icon_32x32@2x.png').must_be_truthy
      end

      it 'returns the 128x128 icons' do
        iconset_files.include?('/config/icons/icon_128x128.png').must_be_truthy
      end

      it 'returns the 128x12?8@2x icons' do
        iconset_files.include?('/config/icons/icon_128x128@2x.png').must_be_truthy
      end
    end

    describe 'tmp_dir' do
      it 'returns a temp directory' do
        Dir.stub(:mktmpdir, '/tmp/t') do
          subject.temp_dir.must_equal '/tmp/t'
        end
      end
    end
  end
end