require File.expand_path '../../test_helper.rb', __FILE__

require 'crusade/notification'
require 'crusade/apns/notification'

describe Crusade::APNS::Notification do
  let(:described_class) { Crusade::APNS::Notification }
  let(:notification)    { Crusade::Notification.new attrs }
  let(:device_token)    { '1234a' }

  let(:attrs) do
    {
      title: 'the title',
      body: 'the body',
      action: 'submit',
      url_args: ['a'],
      device_token: device_token
    }
  end

  describe 'initialize' do
    describe 'with a generic notification' do
      subject { described_class.new notification, device_token }

      it 'delegates the generic properties' do
        subject.title.must_equal 'the title'
      end

      it 'has a device token' do
        subject.device_token.must_equal device_token
      end
    end

    describe 'with a hash of attributes' do
      subject { described_class.new attrs }

      it 'internally builds a generic notification' do
        subject.title.must_equal 'the title'
      end

      it 'has a device token' do
        subject.device_token.must_equal device_token
      end

    end
  end

  describe 'payload and co' do
    subject { described_class.new notification }

    let(:parsed_payload) { JSON.parse(subject.to_json) }
    let(:expected_payload) do
      {
        "aps" => {
          "alert" => {
            "title" => 'the title',
            "body" => 'the body',
            "action" => 'submit'
          },
          "url-args" => ['a']
        }
      }
    end

    it { parsed_payload.must_equal expected_payload }
    it { subject.json_size.must_equal 92 }

    describe 'no url_args' do
      before do
        notification.url_args = []
      end

      it { parsed_payload['aps'].has_key?('url-args').must_be_false }
    end

    describe 'no action' do
      before do
        notification.action = nil
      end

      it { parsed_payload['aps']['alert'].has_key?('action').must_be_false }
    end
  end
end