require File.expand_path '../../test_helper.rb', __FILE__

require 'ostruct'

class FakeEncoder
  def encode notification
    '123'
  end
end

describe Crusade::APNS::PushNotification do
  let(:options) { Fixtures.default_configuration }
  subject { Crusade::APNS::PushNotification.new options, connection }
  let(:connection) { MiniTest::Mock.new }
  let(:notification) { OpenStruct.new(url_args: %w(1)) }

  describe 'send' do
    let(:encoder) { FakeEncoder.new }

    before do
      
    end

    it 'sends the encoded notification' do
      Crusade::APNS::NotificationEncoder.stub(:new, encoder) do
        connection.expect :send,  true, ['123']

        subject.send notification

        connection.verify.must_be_true
      end
    end

    it 'returns :invalid if the number of url args is not the same as in the configuration' do
      notification.url_args = %w(1 2 3)

      result = subject.send notification

      result.must_equal :invalid
    end
  end

  describe 'configuration' do
    it { subject.configuration.must_be_same_as options }
  end
end