require File.expand_path '../../../test_helper.rb', __FILE__
require 'tmpdir'
require 'fileutils'
require 'json'

require 'crusade/apns/push_package/manifest_generator'

describe Crusade::APNS::ManifestGenerator do
  let(:dir) { Dir.mktmpdir }

  before do
    File.open(File.join(dir, 'file_1'), 'w') { |file| file.write("the content\nof the first file")}
    File.open(File.join(dir, 'file_2'), 'w') { |file| file.write("the content\nof the second file")}
    Dir.mkdir File.join(dir, 'sub')
    File.open(File.join(dir, 'sub', 'file_3'), 'w') { |file| file.write("the content\nof the sub file")}
  end

  after { FileUtils.remove_entry_secure dir }

  subject { Crusade::APNS::ManifestGenerator.new dir }

  let(:manifest) { subject.generate }
  let(:parsed) { JSON.parse manifest }

  describe 'generate' do
    it 'generates one entry per file' do
      parsed.keys.must_equal_contents %w(file_1 file_2 sub/file_3)
    end

    it 'digest every file via sha1' do
      parsed['file_1'].must_equal '940a456fdb8c106b98f0481b0badde914bcc878b'
      parsed['file_2'].must_equal '00501364e032879f2262a9932c233ed3497f3f5f'
      parsed['sub/file_3'].must_equal '9c100c8aa0b48975b012073b2cf7ab09d63164e9'
    end
  end

end
