require File.expand_path '../../../test_helper.rb', __FILE__
require 'crusade/apns/push_package/signature_generator'

require 'ssl_support'

require 'tmpdir'
require 'fileutils'

describe Crusade::APNS::SignatureGenerator do
  let(:options) do
    OpenStruct.new(certificate: 'test/fixtures/ssl/certificate.p12', 
                   certificate_password: 'test')
  end

  let(:dir) { Dir.mktmpdir }

  after { FileUtils.remove_entry_secure dir }

  subject { Crusade::APNS::SignatureGenerator.new options }

  describe 'sign' do
    let(:manifest) { File.join dir, 'manifest.json' }
    let(:signature) { File.join(dir, 'signature') }

    before { FileUtils.copy_file "test/fixtures/ssl/manifest_example.json", manifest }

    it 'generates a signature file in the same directory' do
      subject.sign manifest

      File.exist?(signature).must_be_truthy
    end

    it 'uses the certificate to sign the manifest' do
      subject.sign manifest

      certificate = SslSupport.certificate(options.certificate, options.certificate_password)

      SslSupport.verify_signature(certificate, manifest, signature).must_be_truthy
    end
  end
end