require File.expand_path '../../../test_helper.rb', __FILE__

require 'zip_support'

require 'tmpdir'
require 'fileutils'

require 'crusade/apns/push_package/zip_file_generator'

describe Crusade::APNS::ZipFileGenerator do
  let(:options) { Fixtures.default_configuration }

  subject { Crusade::APNS::ZipFileGenerator.new options, dir, destination }

  let(:tmp_dir) { Dir.mktmpdir }
  let(:dir) { File.join tmp_dir, 'push_package' }
  let(:destination) { File.join tmp_dir, 'package.zip' }

  after { FileUtils.remove_entry_secure tmp_dir }

  before { FileUtils.mkdir dir }

  describe 'generate' do
    before do
      File.open(File.join(dir, 'file1.json'), 'w') { |f| f.write 'test' }
      Dir.mkdir File.join(dir, 'sub')
      File.open(File.join(dir, 'sub', 'sub_file'), 'w') { |f| f.write 'test2' }

      subject.generate
    end

    it 'generate a file' do
      File.exists?(destination).must_be_truthy
    end

    it 'archives the files in a zip' do
      expected = [ "file1.json", "sub/", "sub/sub_file"]
      ZipSupport.file_names(destination).must_equal_contents expected
    end
  end

  describe 'clean' do
    it 'removes the zip file' do
      File.open(destination, 'w') { |f| f.write('test') }

      subject.clean

      File.exists?(destination).must_equal false
    end
  end
end
